django microsip inventarios fisicos
==========================

Install or update
-------

### latest version ###
```
pip install djmicrosip_inventarios 
```
### An specific release version ###
```
pip install djmicrosip_inventarios
```
Check installed verion
------------
```
pip freeze | grep djmicrosip_inventarios
```